@@ -309,15 +309,14 @@ xtm_process_window_init (XtmProcessWindow *window)
 	gtk_widget_show (window->treeview);
 	gtk_container_add (GTK_CONTAINER (gtk_builder_get_object (window->builder, "scrolledwindow")), window->treeview);
 
-	g_object_bind_property (gtk_builder_get_object (window->builder, "legend"), "visible",
-			window->settings, "show-legend", G_BINDING_BIDIRECTIONAL);
+	g_object_bind_property(window->settings, "show-legend",
+			gtk_builder_get_object(window->builder, "legend"), "visible",
+			G_BINDING_SYNC_CREATE);
 
 	window->filter_entry = GTK_WIDGET(gtk_builder_get_object (window->builder, "filter-entry"));
 	g_signal_connect (G_OBJECT(window->filter_entry), "icon-press", G_CALLBACK(filter_entry_icon_pressed_cb), NULL);
 	g_signal_connect (G_OBJECT(window->filter_entry), "changed", G_CALLBACK(filter_entry_keyrelease_handler), window->treeview);
 	gtk_widget_set_tooltip_text (window->filter_entry, _("Filter on process name"));
-
-	gtk_widget_grab_focus (GTK_WIDGET (window->filter_entry));
 }
 
 static void
